function test_ACal

% Set Parameters
N = 100; % Dim. signal
L = 10; % Nb. of input Signals
sigma = 0.3; % Amplitude Decalibration
pc = 0.66; % Phase Decalibration
m = 60; % Nb. measurements
K = 10; % Sparsity
Nit = 10000; % Nb. iterations
real_valued = 0; % Real valued simulations instead of complex
savefolder=['Results/ACal/L' num2str(L) '_pc' num2str(pc*100) '_s' num2str(sigma)];
mkdir(savefolder);
savefile=[savefolder '/ACal_N' num2str(N) ...
           '_K' num2str(K) ...
           '_m' num2str(m) '.mat']; % File name to save output

tlimit = 10; % time limit in minutes to end the simulation 
              % (and save data to resume later)
resumefile = [savefolder '/ACal_N' num2str(N) ...
           '_K' num2str(K) ...
           '_m' num2str(m) '_resume.mat']; % the file to save simulation 
                                           % data when the time limit is
                                           % reached

rng('shuffle');
% --- Generate training signals
Xtrue = zeros(N, L);
for ind = 1:L
    I = randperm(N);
    Xtrue(I(1:K), ind) = randn(K, 1);
    if(~real_valued)
    Xtrue(I(1:K), ind) = (Xtrue(I(1:K), ind)+1i*randn(K, 1))/sqrt(2);
    end
end

% --- Measurement process
% Measurement matrix
M = randn(m, N);
if(~real_valued)
    M = (M + 1i*randn(m, N))/sqrt(2);
end
% Decalibration
if(real_valued)
signD = 2*((rand(m, 1)<pc)-.5); %#ok<UNRCH>
else
signD = exp(1i*pc*rand(m, 1)*2*pi);
end

D = (exp(sigma*randn(m,1))).*signD;

% Measurements
Y = diag(D)*M*Xtrue;

% --- Calibration
% Parameters
param.rho = 0.01;
param.verbose = 1;
param.stop_crit = 1e-6;
param.max_iter = Nit;
param.calibrate = 1;
param.tlimit = tlimit;
param.resumefile = resumefile;
if(exist(param.resumefile,'file')) % if already paused before signal that function must resume
    param.resume=1;
end

% Run ADMMM
tic;
[Sol, ~, Outputs] = ACal(Y, M, param); %#ok<ASGLU>

if(Outputs.toberesumed==0)
fprintf('Running time = %e min\n', toc/60);
disp(['Saving results to ' savefile '.mat']);

if(exist(param.resumefile,'file'))
    % Ensure the randomly generated signals stay the same
    load(param.resumefile, 'Xtrue','M','D');
end

save(savefile, 'N', 'K', 'L', 'm', 'Sol', 'Xtrue', 'M', 'D');
disp('Complete!');

if(exist(param.resumefile,'file'))
    % Now that simulation is complete, we can delete earlier resumefile
    delete(param.resumefile);
    disp(['Resume file ' param.resumefile ' is removed']);
end
end

end
