function test_PCalScalable

% Set Parameters
N = 100; % Dim. signal
L = 10; % Nb. of input Signals
m = 60; % Nb. measurements
K = 10; % Sparsity
Nit = 10000; % Nb. iterations
savefolder=['Results/PCalScalable/L' num2str(L)];
mkdir(savefolder);
savefile=[savefolder '/PCalScalable_N' num2str(N) ...
           '_K' num2str(K) ...
           '_m' num2str(m) '.mat']; % File name to save output
       
tlimit = 2; % time limit in minutes to end the simulation 
              % (and save data to resume later)
resumefile = [savefolder '/PCalScalable_N' num2str(N) ...
           '_K' num2str(K) ...
           '_m' num2str(m) '_resume.mat']; % the file to save simulation 
                                           % data when the time limit is
                                           % reached


rng('shuffle');
% --- Generate training signals
Xtrue = zeros(N, L);
for ind = 1:L
    I = randperm(N);
    Xtrue(I(1:K), ind) = (randn(K, 1)+1i*randn(K,1))/sqrt(2);
end

% --- Measurement process
% Measurement matrix
M = (randn(m, N)+1i*randn(m, N))/sqrt(2);
% Decalibration
signD = exp(1i*rand(m, 1)*2*pi);

D = signD;

% Measurements
y = diag(D)*M*Xtrue;
% Cross-product of measurements
Y = cell(L,L);
for l = 1:L
        Y{l,l} = y(:, l).*conj(y(:, l));
        Y{l,mod(l,L)+1} = y(:, l).*conj(y(:, mod(l,L)+1));
end

% --- Calibration
% Parameters
param.N = N;
param.L = L;
param.mu = 50;
param.verbose = 1;
param.stop_crit = 0;
param.max_iter = Nit;
param.Xtrue = Xtrue(:);
param.nb_meas = m;
param.svd_size = 0;
param.convergence_err = 10^(-4);
param.x_org = Xtrue(:);
param.timelimit = tlimit;
param.resume=0;
param.resumefile=resumefile;
if(exist(param.resumefile,'file'))
    param.resume=1;
end

% Run ADMMM
tic;
[X2, iter, Outputs] = PCalScalable(Y, M, param);

if(Outputs.toberesumed==0)
    
fprintf('Running time = %e min (%i iterations)\n', toc/60, iter);
ph=1;
for el=L:-1:1
    temp = [X2{el,el} X2{el,mod(el,L)+1} ; X2{el,mod(el,L)+1}' X2{mod(el,L)+1,mod(el,L)+1}];
    [xrect, lbd] = eigs(temp,1);
    xrect=xrect(:)*sqrt(lbd);
    newph=mean(xrect(N+1:2*N))/abs(mean(xrect(N+1:2*N)));
    xrec(:,el) = xrect(1:N)*ph/newph;
    ph = mean(xrec(:,el))/abs(mean(xrec(:,el)));
end      
Sol = xrec;%#ok<NASGU>

disp(['Saving results to ' savefile]);

if(exist(param.resumefile,'file'))
    load(param.resumefile, 'param','M');
    Xtrue = reshape(param.x_org,N,L); %#ok<NASGU>
end

J_it = Outputs.J_it; %#ok<NASGU>
save(savefile, 'N', 'K', 'L', 'm', 'Sol', 'Xtrue', 'param', 'J_it', 'M','D', 'X2');
disp('Complete!');

if(exist(param.resumefile,'file'))
    delete(param.resumefile);
    disp(['Resume file ' param.resumefile ' is removed']);
end
end

end